from whos_there.senders.base import Sender


class DiscordSender(Sender):
    def __init__(self, webhook_url: str) -> None:
        """Initialize the Discord sender.

        Args:
            webhook_url: The Discord webhook URL.
        """
        super().__init__()
        self.webhook_url = webhook_url

    def send(self, text: str) -> None:
        return self._send_json(self.webhook_url, {"content": text})



import telegram

from whos_there.senders.base import Sender


class TelegramSender(Sender):
    def __init__(self, token: str, chat_id: int) -> None:
        """Initialize the Telegram sender.

        Args:
            token: The Telegram token.
            chat_id: The Telegram chat id.
        """
        super().__init__()
        self.token = token
        self.chat_id = chat_id
        self._bot: telegram.Bot = None

    @property
    def bot(self):
        if not self._bot:
            self._bot = telegram.Bot(token=self.token)
        return self._bot

    def send(self, text: str) -> None:
        return self.bot.send_message(chat_id=self.chat_id, text=text)



from typing import List

from whos_there.senders.base import Sender


class SlackSender(Sender):
    def __init__(self, webhook_url: str, channel: str, user_mentions: List[str] = []) -> None:
        """Initialize the Slack sender.

        Args:
            webhook_url: The Slack webhook URL.
            channel: The Slack channel name.
            user_mentions: The list of users to mention.
        """
        super().__init__()
        self.webhook_url = webhook_url
        self.channel = channel
        self.user_mentions = " ".join(user_mentions)

    def send(self, text: str) -> None:
        data = {
            "username": "Knock Knock",
            "channel": self.channel,
            "link_names": 1,
            "icon_emoji": ":clapper:",  # ":tada:"
            "text": f"{text} {self.user_mentions}",
        }
        return self._send_json(self.webhook_url, data)



from whos_there.senders.debug import DebugSender
from whos_there.senders.discord import DiscordSender
from whos_there.senders.email import EmailSender
from whos_there.senders.slack import SlackSender
from whos_there.senders.teams import TeamsSender
from whos_there.senders.telegram import TelegramSender
